##
##  libelvin.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2008 OpenPKG Foundation e.V. <http://openpkg.net/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         libelvin
Summary:      Elvin Client Library
URL:          http://www.elvin.org/
Vendor:       DTSC/Mantara
Packager:     OpenPKG Foundation e.V.
Distribution: OpenPKG Community
Class:        EVAL
Group:        InstantMessaging
License:      Non-Commercial
Version:      4.0.3
Release:      20080101

#   package options
%option       with_xml      yes
%option       with_ssl      yes
%option       with_threads  no

#   list of sources
Source0:      http://elvin.dstc.com/download/files/libelvin-%{version}.tar.gz
Patch0:       libelvin.patch

#   build information
Prefix:       %{l_prefix}
BuildRoot:    %{l_buildroot}
BuildPreReq:  OpenPKG, openpkg >= 20060823
PreReq:       OpenPKG, openpkg >= 20060823
%if "%{with_ssl}" == "yes"
BuildPreReq:  openssl
PreReq:       openssl
%endif
%if "%{with_xml}" == "yes"
BuildPreReq:  libxml
PreReq:       libxml
%endif
AutoReq:      no
AutoReqProv:  no

%description
    This is the original C client library for the Elvin event routing
    protocol. It supports HTTP/TCP/UDP/Unix as the transport protocol,
    optionally SSL as the security layer and XDR/XML as the marshalling.
    It also provides an Elvin command-line client.

%track
    prog libelvin = {
        disabled
        comment   = "rse: DTSC/Mantara shutdown in 2006 at all"
        version   = %{version}
        url       = http://elvin.dstc.com/download/files/
        regex     = libelvin-(__VER__)\.tar\.gz
    }

%prep
    %setup -q
    %patch -p0

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    ./configure \
        --prefix=%{l_prefix} \
        --sysconfdir=%{l_prefix}/etc/libelvin \
%if "%{with_ssl}" == "yes"
        --with-ssl \
%else
        --without-ssl \
%endif
%if "%{with_xml}" == "yes"
        --with-xml \
%else
        --without-xml \
%endif
%if "%{with_threads}" == "yes"
        --enable-threads \
%else
        --disable-threads \
%endif
        --enable-udp \
        --enable-unix \
        --enable-http \
        --enable-cluster \
        --without-x \
        --without-xt \
        --without-gtk \
        --disable-shared \
        --disable-nls
    %{l_make} %{l_mflags -O}

%install
    rm -rf $RPM_BUILD_ROOT
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    rm -f $RPM_BUILD_ROOT%{l_prefix}/info/dir
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/lib/nls
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean
    rm -rf $RPM_BUILD_ROOT

